UsbDeviceEmulation

Struct UsbDeviceEmulation 

pub struct UsbDeviceEmulation<P: CheckedPermissions>(/* private fields */);

Implementations

Source

impl<P: CheckedPermissions> UsbDeviceEmulation<P>

pub fn register_interface<const N: usize>( &mut self, config: UsbInterfaceConfig<'_, N>, ) -> Result<(UsbRegisteredInterface<P>, [UsbEmulatedEndpoint<P>; N]), UsbError>
where P: MessageAllowed<RegisterInterface>,

Permission: os/usbdev / RegisterInterface

Groups: device-connectivity.usb-device-emulation

Sender policy: signed

Grant timing: grant-on-first-use

Register a disabled interface driver with explicit runtime visibility control. Returns a stable interface handle and the allocated endpoints. Call UsbRegisteredInterface::set_enabled after local setup is ready.

pub fn wait_for_connection(&self) -> Result<(), UsbError>
where P: MessageAllowed<WaitForConnection>,

Permission: os/usbdev / WaitForConnection

Groups: device-connectivity.usb-device-emulation

Sender policy: signed

Grant timing: grant-on-first-use

Wait until the device is configured by the host

pub fn is_enabled(&self) -> Result<bool, UsbError>
where P: MessageAllowed<IsDeviceEmulationEnabled>,

Permission: os/usbdev / IsDeviceEmulationEnabled

Groups: device-connectivity.usb-device-status

Sender policy: signed

Grant timing: install-review

pub fn is_connected(&self) -> Result<bool, UsbError>
where P: MessageAllowed<IsDeviceEmulationConnected>,

Permission: os/usbdev / IsDeviceEmulationConnected

Groups: device-connectivity.usb-device-status

Sender policy: signed

Grant timing: install-review

pub fn is_cable_connected(&self) -> Result<bool, UsbError>
where P: MessageAllowed<IsCableConnected>,

Permission: os/usbdev / IsCableConnected

Groups: device-connectivity.usb-device-status

Sender policy: signed

Grant timing: install-review

Returns true if the USB cable is connected (VBUS has power)

pub fn is_device_mode(&self) -> Result<bool, UsbError>
where P: MessageAllowed<IsDeviceMode>,

Permission: os/usbdev / IsDeviceMode

Groups: device-connectivity.usb-device-status

Sender policy: signed

Grant timing: install-review

Returns true if in USB device mode (not acting as USB host via OTG)

pub fn set_custom_vid_pid(&mut self, vid: Option<u16>, pid: Option<u16>)
where P: MessageAllowed<SetVidPid>,

Permission: os/usbdev / SetVidPid

Groups: device-connectivity.usb-device-control

Sender policy: foundation-signed

Grant timing: policy-only

pub fn reset_controller(&mut self)
where P: MessageAllowed<ResetController>,

Permission: os/usbdev / ResetController

Groups: device-connectivity.usb-device-control

Sender policy: foundation-signed

Grant timing: policy-only