pub struct RegisterInterface {
pub interface_number: u8,
pub if_class: u8,
pub if_subclass: u8,
pub if_protocol: u8,
pub endpoints: Vec<EndpointProperties>,
pub interface_functional_descriptors: Vec<u8>,
pub associated_interface_count: u8,
pub capabilities: Vec<DeviceCapability>,
pub setup_responder: Option<CID>,
}Fields
interface_number: u8if_class: u8if_subclass: u8if_protocol: u8endpoints: Vec<EndpointProperties>interface_functional_descriptors: Vec<u8>associated_interface_count: u8capabilities: Vec<DeviceCapability>setup_responder: Option<CID>Trait Implementations
Sourceimpl Archive for RegisterInterfacewhere
u8: Archive,
Vec<EndpointProperties>: Archive,
Vec<u8>: Archive,
Vec<DeviceCapability>: Archive,
Option<CID>: Archive,
impl Archive for RegisterInterfacewhere
u8: Archive,
Vec<EndpointProperties>: Archive,
Vec<u8>: Archive,
Vec<DeviceCapability>: Archive,
Option<CID>: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedRegisterInterface
type Archived = ArchivedRegisterInterface
The archived representation of this type. Read more
Sourcetype Resolver = RegisterInterfaceResolver
type Resolver = RegisterInterfaceResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for RegisterInterface
impl BlockingArchive for RegisterInterface
Sourceimpl Clone for RegisterInterface
impl Clone for RegisterInterface
Sourcefn clone(&self) -> RegisterInterface
fn clone(&self) -> RegisterInterface
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegisterInterface
impl Debug for RegisterInterface
Sourceimpl<__D: Fallible + ?Sized> Deserialize<RegisterInterface, __D> for Archived<RegisterInterface>where
u8: Archive,
<u8 as Archive>::Archived: Deserialize<u8, __D>,
Vec<EndpointProperties>: Archive,
<Vec<EndpointProperties> as Archive>::Archived: Deserialize<Vec<EndpointProperties>, __D>,
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
Vec<DeviceCapability>: Archive,
<Vec<DeviceCapability> as Archive>::Archived: Deserialize<Vec<DeviceCapability>, __D>,
Option<CID>: Archive,
<Option<CID> as Archive>::Archived: Deserialize<Option<CID>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<RegisterInterface, __D> for Archived<RegisterInterface>where
u8: Archive,
<u8 as Archive>::Archived: Deserialize<u8, __D>,
Vec<EndpointProperties>: Archive,
<Vec<EndpointProperties> as Archive>::Archived: Deserialize<Vec<EndpointProperties>, __D>,
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
Vec<DeviceCapability>: Archive,
<Vec<DeviceCapability> as Archive>::Archived: Deserialize<Vec<DeviceCapability>, __D>,
Option<CID>: Archive,
<Option<CID> as Archive>::Archived: Deserialize<Option<CID>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<RegisterInterface, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<RegisterInterface, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for RegisterInterface
impl MessageId for RegisterInterface
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for RegisterInterfacewhere
u8: Serialize<__S>,
Vec<EndpointProperties>: Serialize<__S>,
Vec<u8>: Serialize<__S>,
Vec<DeviceCapability>: Serialize<__S>,
Option<CID>: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for RegisterInterfacewhere
u8: Serialize<__S>,
Vec<EndpointProperties>: Serialize<__S>,
Vec<u8>: Serialize<__S>,
Vec<DeviceCapability>: Serialize<__S>,
Option<CID>: Serialize<__S>,