Enum EhciError
pub enum EhciError {
InvalidCapsLen,
EndpointNotOpen,
InvalidAddress,
Disconnected,
DescriptorError,
OutOfPoolItems,
SetupUnsuccessful,
Stalled,
ControllerDisabled,
}Expand description
Main error type for the crate
Variants
InvalidCapsLen
The CAPS_LEN field of the Capability Registers was wrong. Possibly means that the controller is not powered, or the base address was wrong.
EndpointNotOpen
The specified endpoint was not opened (See [crate::controller::Controller::open_endpoint])
InvalidAddress
The address specified was out of range.
Disconnected
The addressed device is disconnected.
DescriptorError
The descriptor was malformed
OutOfPoolItems
Could not allocate a pool item for the transfer or async queue
SetupUnsuccessful
There was a fatal error during the setup process of the device
Stalled
The endpoint stalled the transfer
ControllerDisabled
The controller is disabled